@@ -9,7 +9,7 @@ use Text::vCard::Node;
 # See this module for your basic parser functions
 use base qw(Text::vFile::asData);
 use vars qw ($VERSION %lookup %node_aliases @simple);
-$VERSION = '2.02';
+$VERSION = '2.04';
 
 # If the node's data does not break down use this
 my @default_field = qw(value);
@@ -31,7 +31,8 @@ my @default_field = qw(value);
     'TIMEZONE'  => 'TZ',
     'PHONES'    => 'TEL',
     'ADDRESSES' => 'ADR',
-    'NAME'      => 'N',
+    'NAME'      => 'N', # To be depreciated as clashes with RFC
+	'MONIKER'	=> 'N',
 );
 
 # Generate all our simple methods
@@ -165,7 +166,7 @@ my $address = $vcard->add_node({
 This creates a new address in the vCard which you can then call the
 address methods on. See below for what options are available.
 
-The node_type parameter must confirm to the vCard spec format (e.g. ADR not address)
+The node_type parameter must conform to the vCard spec format (e.g. ADR not address)
 
 =cut
 
@@ -281,7 +282,8 @@ or all lowercase method names.
 
   vCard Spec    Alias           Methods on object
   ----------    ----------      -----------------
-  N             name            'family','given','middle','prefixes','suffixes'
+  N             name (depreciated as conflicts with rfc, use moniker)
+  N             moniker            'family','given','middle','prefixes','suffixes'
   ADR           addresses       'po_box','extended','street','city','region','post_code','country'
   GEO                           'lat','long'
   TEL           phones
@@ -533,13 +535,13 @@ Leo Lapworth, LLAP@cuckoo.org
 
 None that I'm aware of - export may not encode correctly.
 
-=head1 SVN
+=head1 Repository (git)
 
-http://code.google.com/p/llap/
+http://github.com/ranguard/text-vcard
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Leo Lapworth. All rights reserved.
+Copyright (c) 2005-2010 Leo Lapworth. All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
